#### Please select the sections that you would like to print

Select All
Case Information
Party
Disposition Events
Events and Hearings
Financial
Print

# Case Information

17D22499 | ARBOR CROSSING APTS - CF PROPERTY MGMT CO VS KAIA YAAMEEN,AND ALL OTHER OCCUPANTS

Case Number
17D22499

Court
Division 0

Judicial Officer
Anderson, Berryl A

File Date
08/21/2017

Case Type
Magistrate Dispossessory - Non Payment of Rent

Case Status
Closed

# Party

Plaintiff
ARBOR CROSSING APTS - CF PROPERTY MGMT CO

Address

10 ARBOR CRSSING DRIVE
LITHONIA GA 30058

Active Attorneys

Lead Attorney
Passino, David R

Retained

Defendant
YAAMEEN, KAIA A

Address

10 ARBOR CROSSING DRIVE, UNIT 1008
LITHONIA GA 30058

Defendant
ALL OTHER OCCUPANTS, AND

Address

10 ARBOR CROSSING DRIVE, UNIT 1008
LITHONIA GA 30058

# Disposition Events

09/14/2017 Judgment

Judicial Officer
Leshaw, Gary

Judgment Type
Order and Judgment

Award

Judgment For: Plaintiff

Verdict to Plaintiff:

Compensatory: $1,903.00

Verdict on Cross/Counter Claim:

# Events and Hearings

- 08/21/2017 Dispossessory Warrant

  Comment
  FILING

- 08/24/2017 Dispossessory Service

  Unserved

  Anticipated Server
  Private Process Servers

  Anticipated Method

- 09/05/2017 Dispossessory Answer

- 09/14/2017 Dispossessory Attorney

  Judicial Officer
  Anderson, Berryl A

  Hearing Time
  9:00 AM

- 09/22/2017 Writ Application Issued

  Comment
  writ request

- 09/26/2017 Writ application sent to judge

- 09/27/2017 Writ To Marshal

- 09/27/2017 Writ Service

  Unserved

  Anticipated Server
  Marshal

  Anticipated Method

- 10/23/2017 Tenant Ejected

  Comment
  trash out

Loading financial, please wait...